@@ -178,7 +178,7 @@ class config_handler:
         parser.add_argument(
             "--prompt",
             help="Customizes the prompt display",
-            default=f"┌─[{getlogin().capitalize()}@chatgpt3]─(%H:%M:%S)",
+            default=f"┌─[{getlogin().capitalize()}@ChatGPT4]─(%H:%M:%S)",
             dest="settings",
             nargs="*",
         )
@@ -288,6 +288,11 @@ class config_handler:
             help="Download latest prompts - [awesome-chatgpt-prompts]",
             action="store_true",
         )
+        parser.add_argument(
+            "--sudo",
+            help="Run commands against system with sudo privileges",
+            action="store_true",
+        )
         return parser.parse_args()
 
     def main(self):
@@ -309,6 +314,7 @@ from os import system, remove, path, environ, makedirs
 from threading import Thread as thr
 from appdirs import AppDirs
 from rich.markdown import Markdown
+from .addons import file_parser, system_control
 
 app_dir = AppDirs(
     "smartwa",
@@ -533,16 +539,17 @@ class main_gpt(cmd.Cmd):
     color_dict = config_handler.color_dict
     bcolor_dict = config_handler.bcolor_dict
     interactive = local_interactor()
+    parser = lambda self, line: file_parser(line).parse()
 
     def apply_color(self):
         print(
             self.bcolor_dict[args.background_color] + self.color_dict[args.input_color]
         )
 
-    def prompt_is_error_free(self,prompt,resp=True) -> bool:
+    def prompt_is_error_free(self, prompt, resp=True) -> bool:
         """Checks if prompt contains [sorry]"""
-        if isinstance(prompt,list):
-            if len(prompt)>=2 and prompt[0:2]==["I'm","sorry"]:
+        if isinstance(prompt, list):
+            if len(prompt) >= 2 and prompt[0:2] == ["I'm", "sorry"]:
                 resp = False
         else:
             if prompt.startswith("I'm sorry"):
@@ -550,15 +557,17 @@ class main_gpt(cmd.Cmd):
         return resp
 
     def default(self, raw, return_fb=False):
-        if not bool(raw):
+        raw = self.parser(raw)
+        run_against_system = False
+        if not raw:
             return
         # out = lambda b: print(self.color_dict[args.output_color] + b + Fore.RESET)
         if raw[0:2] == "./":
             system((raw[2:]).strip())
-            print()
         else:
-            if not bool(raw):
-                return
+            if "--system" in raw:
+                run_against_system = True
+                raw = raw.replace("--system", "")
             args.message = raw
             print(self.color_dict[args.output_color], end="")
             rp = gpt3.main()
@@ -567,6 +576,8 @@ class main_gpt(cmd.Cmd):
                 if return_fb:
                     return feedback.strip()
                 record_keeper.main(feedback)
+                if run_against_system:
+                    system_control(feedback).execute(args.sudo)
 
             else:
                 logging.error(str(rp[1]))
@@ -575,6 +586,9 @@ class main_gpt(cmd.Cmd):
 
     def do_txt2img(self, line):
         """Generate images based on GPT description"""
+        line = self.parser(line)
+        if not line:
+            return
         print(
             self.color_dict[args.output_color] + ">>[*] Querying description from GPT",
             end="\r",
@@ -596,8 +610,11 @@ class main_gpt(cmd.Cmd):
             if not description:
                 logging.error("Failed to generate description.")
         self.do__prompt(self.prompt_disp)
-                
+
     def do_img(self, line):
+        line = self.parser(line)
+        if not line:
+            return
         """Text-to-Image handler"""
         print(self.color_dict[args.output_color], end="\r")
         resp = imager(line.split(" ")).main()
@@ -607,6 +624,9 @@ class main_gpt(cmd.Cmd):
         self.do__prompt(self.prompt_disp)
 
     def do_emg(self, line, args_parsed=False):
+        line = self.parser(line)
+        if not line:
+            return
         print(
             self.color_dict[args.input_color if args_parsed else args.output_color],
             end="\r",
@@ -629,6 +649,9 @@ class main_gpt(cmd.Cmd):
         self.do__prompt(self.prompt_disp)
 
     def do__prompt(self, line):
+        line = self.parser(line)
+        if not line:
+            return
         """Modify prompts"""
         self.prompt_disp = line
         self.prompt = time_now_format(line)
@@ -720,6 +743,9 @@ class main_gpt(cmd.Cmd):
         print(help)
         self.do__prompt(self.prompt_disp)
 
+    def do__exit(self, line):
+        return True
+
 
 def get_api_key() -> str:
     """Gets API from Key_path or args.key"""
@@ -778,6 +804,7 @@ def intro_train(
             logging.warning(error_msg)
     else:
         logging.warning(error_msg)
+    del prompt_dict, keys
 
 
 def main():
@@ -790,11 +817,13 @@ def main():
     try:
         if args.gpt in ("4"):
             from revChatGPT.V3 import Chatbot
-            
+
             gpt4 = True
             chatbot = Chatbot(
                 api_key=args.api_key,
-                engine=args.model if args.model in config_h.v4models else "gpt-3.5-turbo",
+                engine=args.model
+                if args.model in config_h.v4models
+                else "gpt-3.5-turbo",
                 # timeout=args.timeout, #Available as from revChatGPT>=4.0.6.1
                 proxy=args.proxy,  #
                 max_tokens=args.max_tokens,
@@ -805,21 +834,24 @@ def main():
                 system_prompt=args.system_prompt
                 if args.system_prompt is str
                 else " ".join(args.system_prompt),
-                )
+            )
         else:
             gpt4 = False
             from revChatGPT.V0 import Chatbot
+
             chatbot = Chatbot(api_key=args.api_key, engine=args.model, proxy=args.proxy)
     except Exception as e:
         exit(logging.critical(getExc(e)))
-        
+
     try:
         if args.new_record and path.isfile(args.output):
             remove(args.output)
         run = main_gpt()
         if args.message:
             run.default(
-                " ".join(args.message) if args.message is list else args.message
+                " ".join(run.parser(args.message))
+                if args.message is list
+                else args.message
             )
         run.cmdloop()
     except (KeyboardInterrupt, EOFError):
